@@ -19,6 +19,7 @@ from osc_lib.tests import utils
 import yaml
 
 from tripleoclient import exceptions
+from tripleoclient.tests import fakes
 from tripleoclient.v1 import overcloud_parameters
 
 
@@ -26,8 +27,10 @@ class TestSetParameters(utils.TestCommand):
 
     def setUp(self):
         super(TestSetParameters, self).setUp()
-
-        self.cmd = overcloud_parameters.SetParameters(self.app, None)
+        app_args = mock.Mock()
+        app_args.verbose_level = 1
+        self.app.options = fakes.FakeOptions()
+        self.cmd = overcloud_parameters.SetParameters(self.app, app_args)
         self.app.client_manager.workflow_engine = mock.Mock()
 
         self.workflow = self.app.client_manager.workflow_engine
@@ -52,18 +55,16 @@ class TestSetParameters(utils.TestCommand):
             })
         )
 
+        playbook_runner = mock.patch(
+            'tripleoclient.utils.run_ansible_playbook',
+            autospec=True
+        )
+        playbook_runner.start()
+        self.addCleanup(playbook_runner.stop)
+
         # Run
         self.cmd.take_action(parsed_args)
 
-        # Verify
-        self.workflow.action_executions.create.assert_called_once_with(
-            'tripleo.parameters.update',
-            {
-                'container': 'overcast',
-                'parameters': data.get('parameter_defaults', data)
-            },
-            run_sync=True, save_result=True)
-
     def test_json_params_file(self):
         self._test_set_parameters(".json", json.dumps, {
             "param1": "value1",
