@@ -21,11 +21,14 @@ from osc_lib.i18n import _
 from osc_lib import utils
 
 from tripleoclient import command
-from tripleoclient import constants
 from tripleoclient import exceptions
 from tripleoclient import export
 
 
+MISTRAL_VAR = os.environ.get('MISTRAL_VAR',
+                             "/var/lib/mistral/")
+
+
 class ExportCell(command.Command):
     """Export cell information used as import of another cell"""
 
@@ -53,11 +56,6 @@ class ExportCell(command.Command):
         parser.add_argument('--output-file', '-o', metavar='<output file>',
                             help=_('Name of the output file for the cell data '
                                    'export. It will default to "<name>.yaml"'))
-        parser.add_argument('--config-download-dir',
-                            action='store',
-                            help=_('Directory to search for config-download '
-                                   'export data. Defaults to '
-                                   '$HOME/config-download'))
         parser.add_argument('--force-overwrite', '-f', action='store_true',
                             default=False,
                             help=_('Overwrite output file if it exists.'))
@@ -92,13 +90,7 @@ class ExportCell(command.Command):
             stack_to_export = cell_stack
             should_filter = False
 
-        if not parsed_args.config_download_dir:
-            download_dir = constants.DEFAULT_WORK_DIR
-        else:
-            download_dir = parsed_args.config_download_dir
-
-        config_download_dir = os.path.join(download_dir, stack_to_export)
-
+        config_download_dir = os.path.join(MISTRAL_VAR, stack_to_export)
         data.update(export.export_stack(
             clients.orchestration, stack_to_export, should_filter,
             config_download_dir))
